@@ -484,7 +484,7 @@ def create_update_query(item_id, update_value):
             }
         }""" % (
         item_id,
-        json.dumps(update_value),
+        json.dumps(update_value, ensure_ascii=False),
     )
 
     return query
@@ -742,53 +742,3 @@ def get_activity_logs_query(
     )
 
     return query
-
-
-def get_docs_query(object_id: str, page: int = 1) -> str:
-    """
-    Get docs query for a specific object_id with pagination support.
-    
-    Args:
-        object_id: The object ID to fetch docs for
-        page: Page number to fetch (default: 1)
-    
-    Returns:
-        GraphQL query string
-    """
-    query = """query {
-        complexity {
-            query
-            after
-        }
-        docs (object_ids: %s) {
-            id
-            created_at
-            created_by {
-                id
-                name
-            }
-            doc_folder_id
-            doc_kind
-            name
-            url
-            workspace {
-                name
-            }
-            workspace_id
-            object_id
-            settings
-            blocks (page: %s) {
-                type
-                content
-                position
-                updated_at
-                id
-                parent_block_id
-            }
-        }
-    }""" % (
-        object_id,
-        page,
-    )
-
-    return query
